###########################
# Creating Case Study R0(t) Figure
###########################

# Clear workspace and load packages
# rm(list = ls())
# setwd("/Users/hurford1/Desktop/Test_Revise") # Set this to preferred working directory 
library(ggplot2)
library(scales)
library(cowplot)

# Making panel A: R0(t)
R0_nova <- read.csv("R0_nova")
R0_nova

R0_BC <- read.csv("R0_BC")
R0_BC

R0_lab <- read.csv("R0_lab")

start.date <- seq(1, 365, 30)

R0_combined <- cbind(start.date, R0_nova, R0_BC, R0_lab)
R0_combined
names(R0_combined) <- c("start.date", "R0.nova", "R0.BC", "R0.lab")

R0.plot <- ggplot(data = R0_combined, aes(x = start.date, y = R0.nova / R0.lab)) +
  geom_point(data = R0_combined, aes(x = start.date, y = R0.nova / R0.lab), 
             colour = "black", size = 3) +
  geom_point(data = R0_combined, aes(x = start.date, y = R0.BC / R0.lab), 
             colour = "black", size = 3) +
  geom_line(linetype = "solid", aes(x = start.date, y =  R0.nova / R0.lab, color = "NL")) +
  geom_line(linetype = "solid", aes(x = start.date, y =  R0.BC / R0.lab, color = "BC")) +
  scale_color_manual("",values = c("BC" = "darkgreen", "NL" = "purple")) +
  labs(x = "Day of the Year", y = expression(paste(bar(R)[e](t))), 
       title = expression(bold(paste("Relative Reproductive Effort Ratio, ", bar(R)[e](t))))) 

# Panel B: Forward Delays
tauhatsNL <- read.csv("tauhatsNL.csv")
tauhatsBC <- read.csv("tauhatsBC.csv")

tauhats.both <- as.data.frame(cbind(tauhatsNL, tauhatsBC))

tauhats.plot <- ggplot(data = tauhats.both, aes(x = DoY, y = tauhatP)) +
  geom_line(aes(x = daysP.NL, y =  tauhatP.NL, color = "tauhatP.NL", linetype = "tauhatP.NL")) + 
  geom_line(aes(x = daysC.NL, y =  tauhatC.NL, color = "tauhatC.NL", linetype = "tauhatC.NL")) + 
  geom_line(aes(x = daysP.BC, y =  tauhatP.BC, color = "tauhatP.BC", linetype = "tauhatP.BC")) + 
  geom_line(aes(x = daysC.BC, y =  tauhatC.BC, color = "tauhatC.BC", linetype = "tauhatC.BC")) + 
  labs(x = "Day of the Year", y = expression(Time(Days)), title = "Development Time") + 
  scale_linetype_manual("", values = c("tauhatP.BC" = "dashed", "tauhatC.BC" = "solid", 
                                       "tauhatP.NL" = "dashed", "tauhatC.NL" = "solid" ),
                        labels = c(expression(tau[C]~BC), expression(tau[C]~NL),
                                   expression(tau[P]~BC), expression(tau[P]~NL))) +
  scale_color_manual("", values = c("tauhatP.BC" = "darkgreen", "tauhatC.BC" = "darkgreen",
                                    "tauhatP.NL" = "purple", "tauhatC.NL" = "purple"),
                     labels = c(expression(tau[C]~BC), expression(tau[C]~NL),
                                expression(tau[P]~BC), expression(tau[P]~NL))) +
  xlim(0, 365) + ylim(0, 160)
tauhats.plot

# Panel C: Mortalities
MortalityNL <- read.csv("MortalityNL.csv")
MortalityBC <- read.csv("MortalityBC.csv")

mortality.both <- as.data.frame(cbind(MortalityNL$DoY, 
                                      MortalityNL$mortality.p,
                                      MortalityNL$mortality.a, 
                                      MortalityBC$mortality.p,
                                      MortalityBC$mortality.a))
names(mortality.both) <- c("DoY", "mup.NL", "mua.NL", "mup.BC", "mua.BC" )

mortality.plot <- ggplot(data = mortality.both, aes(x = DoY, y = mup.BC)) +
  geom_line(aes(x = DoY, y =  mup.NL, color = "mup.NL", linetype = "mup.NL")) + 
  geom_line(aes(x = DoY, y =  mua.NL, color = "mua.NL", linetype = "mua.NL")) + 
  geom_line(aes(x = DoY, y =  mup.BC, color = "mup.BC", linetype = "mup.BC")) + 
  geom_line(aes(x = DoY, y =  mua.BC, color = "mua.BC", linetype = "mua.BC")) +   
  labs(x = "Day of the Year", y = expression(Mortality (1/d)), title = "Mortality") + 
  scale_linetype_manual("", values = c("mup.NL" = "dashed", "mua.NL" = "solid", 
                                   "mup.BC" = "dashed", "mua.BC" = "solid"),
                        labels = c(expression(mu[A]~BC), expression(mu[A]~NL),
                                   expression(mu[P]~BC), expression(mu[P]~NL))) +
  scale_color_manual("", values = c("mup.BC" = "darkgreen", "mua.BC" = "darkgreen",
                                    "mup.NL" = "purple", "mua.NL" = "purple"),
                     labels = c(expression(mu[A]~BC), expression(mu[A]~NL),
                                expression(mu[P]~BC), expression(mu[P]~NL))) +
  xlim(0, 365) + ylim(0, 0.2)

# Data for panels D and E
BC.environment <- read.csv("BCenvironment")
NL.environment <- read.csv("NLenvironment")

# Panel D: Temperature in NL and BC
ggTEMP <- ggplot(data = NL.environment, 
                 aes(x = as.Date(as.POSIXct(timevalues, origin = '1970-01-01')), 
                     y = predictedTEMP)) +
geom_point(data = NL.environment,
           aes(x = as.Date(as.POSIXct(unclassed.time - (31556940 * 10), 
                                      origin = '1970-01-01')), 
               y =  T3, color = "NL")) +
geom_line(data = NL.environment,
           aes(x = as.Date(as.POSIXct(unclassed.time - (31556940 * 10), 
                                      origin = '1970-01-01')), 
               y =  T3, color = "NL"), alpha = 0) + 
geom_line(data = NL.environment,
          aes(x = as.Date(as.POSIXct(timevalues - (31556940 * 10), 
                                     origin = '1970-01-01')), 
              y =  predictedTEMP, color = "lm NL")) + 
geom_point(data = BC.environment, 
           aes(x = as.Date(as.POSIXct(unclassed.time, origin = '1970-01-01')), 
               y =  f3.temperature, color = "BC")) +
geom_line(data = BC.environment, 
          aes(x = as.Date(as.POSIXct(unclassed.time, origin = '1970-01-01')), 
              y =  f3.temperature, color = "BC"), alpha = 0) +
geom_line(data = BC.environment,
          aes(x = as.Date(as.POSIXct(timevalues, origin = '1970-01-01')), 
              y =  predictedTEMP, color = "lm BC")) +
scale_x_date(limits = c(as.Date("2003-1-1"), as.Date("2003-12-31")), 
             breaks = "4 months", labels = date_format("%b")) +
scale_linetype_manual(values = c("solid", "blank", "solid", "blank"),
                      guide = FALSE) + 
scale_colour_manual(values = c("green", "darkgreen", "purple", "pink"),
                    guide = guide_legend(override.aes = list(
                    linetype = c("blank", "solid", "solid", "blank"),
                    size = c(2, 1, 1, 2)),
                    title = NULL)) +
labs(x = "Day of the Year", y = expression(~degree~C), title = "Temperature") +
ylim(0, 25)

# Panel E: Salinity in NL and BC
ggSAL <- ggplot(data = NL.environment, 
                aes(x = as.Date(as.POSIXct(timevalues, origin = '1970-01-01')), 
                    y = predictedPSU)) +
geom_point(data = NL.environment,
          aes(x = as.Date(as.POSIXct(unclassed.time - (31556940 * 10), 
                                     origin = '1970-01-01')), 
              y =  PSU3, color = "NL")) + 
geom_line(data = NL.environment,
          aes(x = as.Date(as.POSIXct(unclassed.time - (31556940 * 10), 
                                     origin = '1970-01-01')), 
              y =  PSU3, color = "NL"), alpha = 0) + 
geom_line(data = NL.environment, linetype = "solid", 
          aes(x = as.Date(as.POSIXct(timevalues - (31556940 * 10), 
                                     origin = '1970-01-01')), 
              y =  predictedPSU, color = "lm NL", linetype = "NL")) + 
geom_point(data = BC.environment,
           aes(x = as.Date(as.POSIXct(unclassed.time, origin = '1970-01-01')), 
               y =  f3.salinity, color = "BC")) +
geom_line(data = BC.environment,
          aes(x = as.Date(as.POSIXct(unclassed.time, origin = '1970-01-01')), 
              y =  f3.salinity, color = "BC"), alpha = 0) +
geom_line(data = BC.environment, linetype = "solid", 
          aes(x = as.Date(as.POSIXct(timevalues, origin = '1970-01-01')), 
              y =  predictedPSU, color = "lm BC", linetype = "BC")) +
scale_x_date(limits = c(as.Date("2003-1-1"), as.Date("2003-12-31")), 
             breaks = "4 months", labels = date_format("%b")) +
scale_linetype_manual(values = c("blank", "solid", "blank", "solid"),
                      guide = FALSE) + 
scale_colour_manual(values = c("green", "darkgreen", "purple", "pink"),
                    guide = guide_legend(override.aes = list(
                    linetype = c("blank", "solid", "solid", "blank"),
                    size = c(2, 1, 1, 2)),
                    title = NULL)) +
labs(x = "Day of the Year", y = expression(Salinity (psu)), title = "Salinity") +
ylim(15, 35)

# Combining the 5 Panels and Saving the Figure
R0.plot
tauhats.plot
mortality.plot
ggTEMP # Will not work without NL environmental data
ggSAL # Will not work without NL environmental data
case.study.plot2 <- plot_grid(R0.plot, tauhats.plot, mortality.plot, ggTEMP, 
                              ggSAL, nrow = 5, ncol = 1, 
                              labels = c("A", "B", "C" , "D", "E"))
case.study.plot2
ggsave(filename = "R0t2.pdf", plot = case.study.plot2, width = 9.39, height = 9.67)

